==> nextcloud-app-mail-4.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/bn_BD.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "গুরুত্বপূর্ণ",
    "Work" : "কর্মস্থল",
    "Personal" : "ব্যক্তিগত",
    "Mail" : "মেইল",
    "Name" : "নাম",
    "Password" : "কূটশব্দ",
    "None" : "কোনটিই নয়",
    "Save" : "সংরক্ষণ",
    "Connect" : "সংযুক্ত হও",
    "Go back" : "ফিরে যাও",
    "Cancel" : "বাতির",
    "General" : "সাধারণ",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Delete" : "মুছে",
    "Search" : "Search",
    "Send" : "পাঠাও",
    "Refresh" : "নবোদ্যম",
    "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
    "Choose" : "বেছে নিন",
    "Favorite" : "প্রিয়জন",
    "Read" : "পড়",
    "Edit tags" : "ট্যাগ সম্পাদনা",
    "Back" : "পেছনে যাও",
    "Description" : "বিবরণ",
    "Create" : "তৈরী কর",
    "Select" : "সিলেক্ট",
    "Comment" : "মন্তব্য",
    "Remove" : "অপসারণ",
    "Other" : "অন্যান্য",
    "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
    "Move" : "Move",
    "Quota" : "কোটা",
    "Mark all as read" : "সব পঠিত হিসেবে চিহ্নিত কর",
    "Rename" : "পূনঃনামকরণ",
    "Clear cache" : "ক্যাশে পরিষ্কার কর",
    "Sending …" : "পাঠানো হচ্ছে......",
    "Reply" : "জবাব",
    "Add" : "যোগ করুন",
    "Close" : "বন্ধ",
    "Date" : "Date",
    "Tags" : "ট্যাগ",
    "Actions" : "পদক্ষেপসমূহ",
    "Reset" : "পূণঃনির্ধানণ",
    "Client ID" : "ক্লায়েন্ট পরিচিতি",
    "User" : "User",
    "Host" : "হোস্ট",
    "Port" : "পোর্ট",
    "All" : "সবাই",
    "Favorites" : "প্রিয়জন"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.1.9-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/bn_BD.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "গুরুত্বপূর্ণ",
    "Work" : "কর্মস্থল",
    "Personal" : "ব্যক্তিগত",
    "Mail" : "মেইল",
    "Save" : "সংরক্ষণ",
    "Connect" : "সংযুক্ত হও",
    "Name" : "নাম",
    "Password" : "কূটশব্দ",
    "None" : "কোনটিই নয়",
    "Go back" : "ফিরে যাও",
    "Cancel" : "বাতির",
    "Accounts" : "Accounts",
    "General" : "সাধারণ",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Delete" : "মুছে",
    "Search" : "Search",
    "Send" : "পাঠাও",
    "Refresh" : "নবোদ্যম",
    "Choose" : "বেছে নিন",
    "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
    "Favorite" : "প্রিয়জন",
    "Read" : "পড়",
    "Edit tags" : "ট্যাগ সম্পাদনা",
    "Back" : "পেছনে যাও",
    "Description" : "বিবরণ",
    "Create" : "তৈরী কর",
    "Select" : "সিলেক্ট",
    "Comment" : "মন্তব্য",
    "Remove" : "অপসারণ",
    "Other" : "অন্যান্য",
    "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
    "Move" : "Move",
    "Folder name" : "ফোলডারের নাম",
    "Mark all as read" : "সব পঠিত হিসেবে চিহ্নিত কর",
    "Rename" : "পূনঃনামকরণ",
    "Clear cache" : "ক্যাশে পরিষ্কার কর",
    "Reply" : "জবাব",
    "Add" : "যোগ করুন",
    "Close" : "বন্ধ",
    "Date" : "Date",
    "Tags" : "ট্যাগ",
    "Reset" : "পূণঃনির্ধানণ",
    "Client ID" : "ক্লায়েন্ট পরিচিতি",
    "User" : "User",
    "Host" : "হোস্ট",
    "Port" : "পোর্ট",
    "All" : "সবাই",
    "Favorites" : "প্রিয়জন",
    "Actions" : "পদক্ষেপসমূহ"
},
"nplurals=2; plural=(n != 1);");
